@@ -1,7 +1,7 @@
 package App::shcompgen;
 
 our $DATE = '2014-12-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -321,7 +321,7 @@ sub _generate_or_remove {
                     next PROG;
                 }
             }
-            $log->debugf("Writing completion script to %s ...", $comppath);
+            $log->infof("Writing completion script to %s ...", $comppath);
             eval { write_file($comppath, $script) };
             if ($@) {
                 $envres->add_result(500, "Can't write to '$comppath': $@",
@@ -334,7 +334,7 @@ sub _generate_or_remove {
         if ($which eq 'remove') {
             my $comppath = _completion_script_path(%args, prog => $prog);
             unless (-f $comppath) {
-                $log->infof("Skipping %s (completion script does not exist)", $prog0);
+                $log->debugf("Skipping %s (completion script does not exist)", $prog0);
                 next PROG;
             }
             my $content;
@@ -347,7 +347,7 @@ sub _generate_or_remove {
                 $log->debugf("Skipping %s, not installed by us", $prog0);
                 next;
             }
-            $log->debugf("Unlinking %s ...", $comppath);
+            $log->infof("Unlinking %s ...", $comppath);
             if (unlink $comppath) {
                 $envres->add_result(200, "OK", {item_id=>$prog0});
             } else {
@@ -422,7 +422,7 @@ _
     $instruction .= "Congratulations, shcompgen initialization is successful.\n\n";
 
     unless (-d $dir) {
-        make_path($args{bash_global_dir});
+        make_path($dir) or return [500, "Can't create $dir: $!"];
         $instruction .= "Directory '$dir' created.\n\n";
     }
 
@@ -502,7 +502,7 @@ sub list {
             $log->warnf("Can't open file '%s': %s", $comppath, $@);
             next;
         };
-        unless ($content =~ /^# FRAGMENT id=shcompgen-header note=(.+)\b/m) {
+        unless ($content =~ /^# FRAGMENT id=shcompgen-header note=(.+)(?:\s|$)/m) {
             $log->debugf("Skipping prog %s, not generated by us", $entry);
             next;
         }
@@ -562,7 +562,7 @@ App::shcompgen - Backend for shcompgen script
 
 =head1 VERSION
 
-This document describes version 0.02 of App::shcompgen (from Perl distribution App-shcompgen), released on 2014-12-13.
+This document describes version 0.03 of App::shcompgen (from Perl distribution App-shcompgen), released on 2014-12-13.
 
 =head1 FUNCTIONS
 
